@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.RDSDataService 1.24.64\nVersion:         1.24.64\nBuilder"
-        " version: 7.11.8\nDocs:           "
+        "Type annotations for boto3.RDSDataService 1.26.0\nVersion:         1.26.0.post1\nBuilder"
+        " version: 7.11.10\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rds_data//\nBoto3 docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds-data.html#RDSDataService\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.24.64")
+    print("1.26.0.post1")
 
 
 def main() -> None:
