@@ -108,7 +108,9 @@ ServiceName = Literal[
     "connect",
     "connect-contact-lens",
     "connectcampaigns",
+    "connectcases",
     "connectparticipant",
+    "controltower",
     "cur",
     "customer-profiles",
     "databrew",
@@ -186,6 +188,7 @@ ServiceName = Literal[
     "iotevents",
     "iotevents-data",
     "iotfleethub",
+    "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
@@ -241,6 +244,7 @@ ServiceName = Literal[
     "mgn",
     "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhuborchestrator",
     "migrationhubstrategy",
     "mobile",
     "mq",
