@@ -26,76 +26,52 @@ else:
 
 __all__ = (
     "ArrayValueTypeDef",
-    "BatchExecuteStatementRequestRequestTypeDef",
-    "BatchExecuteStatementResponseTypeDef",
+    "ResponseMetadataTypeDef",
     "BeginTransactionRequestRequestTypeDef",
-    "BeginTransactionResponseTypeDef",
     "ColumnMetadataTypeDef",
     "CommitTransactionRequestRequestTypeDef",
-    "CommitTransactionResponseTypeDef",
     "ExecuteSqlRequestRequestTypeDef",
-    "ExecuteSqlResponseTypeDef",
-    "ExecuteStatementRequestRequestTypeDef",
-    "ExecuteStatementResponseTypeDef",
+    "ResultSetOptionsTypeDef",
     "FieldTypeDef",
     "RecordTypeDef",
-    "ResponseMetadataTypeDef",
-    "ResultFrameTypeDef",
-    "ResultSetMetadataTypeDef",
-    "ResultSetOptionsTypeDef",
     "RollbackTransactionRequestRequestTypeDef",
-    "RollbackTransactionResponseTypeDef",
-    "SqlParameterTypeDef",
-    "SqlStatementResultTypeDef",
     "StructValueTypeDef",
-    "UpdateResultTypeDef",
     "ValueTypeDef",
+    "BeginTransactionResponseTypeDef",
+    "CommitTransactionResponseTypeDef",
+    "RollbackTransactionResponseTypeDef",
+    "ResultSetMetadataTypeDef",
+    "ExecuteStatementResponseTypeDef",
+    "SqlParameterTypeDef",
+    "UpdateResultTypeDef",
+    "ResultFrameTypeDef",
+    "BatchExecuteStatementRequestRequestTypeDef",
+    "ExecuteStatementRequestRequestTypeDef",
+    "BatchExecuteStatementResponseTypeDef",
+    "SqlStatementResultTypeDef",
+    "ExecuteSqlResponseTypeDef",
 )
 
 ArrayValueTypeDef = TypedDict(
     "ArrayValueTypeDef",
     {
-        "arrayValues": Sequence[Dict[str, Any]],
         "booleanValues": Sequence[bool],
-        "doubleValues": Sequence[float],
         "longValues": Sequence[int],
+        "doubleValues": Sequence[float],
         "stringValues": Sequence[str],
+        "arrayValues": Sequence[Dict[str, Any]],
     },
     total=False,
 )
 
-_RequiredBatchExecuteStatementRequestRequestTypeDef = TypedDict(
-    "_RequiredBatchExecuteStatementRequestRequestTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "resourceArn": str,
-        "secretArn": str,
-        "sql": str,
-    },
-)
-_OptionalBatchExecuteStatementRequestRequestTypeDef = TypedDict(
-    "_OptionalBatchExecuteStatementRequestRequestTypeDef",
-    {
-        "database": str,
-        "parameterSets": Sequence[Sequence["SqlParameterTypeDef"]],
-        "schema": str,
-        "transactionId": str,
-    },
-    total=False,
-)
-
-
-class BatchExecuteStatementRequestRequestTypeDef(
-    _RequiredBatchExecuteStatementRequestRequestTypeDef,
-    _OptionalBatchExecuteStatementRequestRequestTypeDef,
-):
-    pass
-
-
-BatchExecuteStatementResponseTypeDef = TypedDict(
-    "BatchExecuteStatementResponseTypeDef",
-    {
-        "updateResults": List["UpdateResultTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -122,31 +98,23 @@ class BeginTransactionRequestRequestTypeDef(
     pass
 
 
-BeginTransactionResponseTypeDef = TypedDict(
-    "BeginTransactionResponseTypeDef",
-    {
-        "transactionId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ColumnMetadataTypeDef = TypedDict(
     "ColumnMetadataTypeDef",
     {
-        "arrayBaseColumnType": int,
-        "isAutoIncrement": bool,
-        "isCaseSensitive": bool,
-        "isCurrency": bool,
-        "isSigned": bool,
-        "label": str,
         "name": str,
+        "type": int,
+        "typeName": str,
+        "label": str,
+        "schemaName": str,
+        "tableName": str,
+        "isAutoIncrement": bool,
+        "isSigned": bool,
+        "isCurrency": bool,
+        "isCaseSensitive": bool,
         "nullable": int,
         "precision": int,
         "scale": int,
-        "schemaName": str,
-        "tableName": str,
-        "type": int,
-        "typeName": str,
+        "arrayBaseColumnType": int,
     },
     total=False,
 )
@@ -160,19 +128,11 @@ CommitTransactionRequestRequestTypeDef = TypedDict(
     },
 )
 
-CommitTransactionResponseTypeDef = TypedDict(
-    "CommitTransactionResponseTypeDef",
-    {
-        "transactionStatus": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredExecuteSqlRequestRequestTypeDef = TypedDict(
     "_RequiredExecuteSqlRequestRequestTypeDef",
     {
-        "awsSecretStoreArn": str,
         "dbClusterOrInstanceArn": str,
+        "awsSecretStoreArn": str,
         "sqlStatements": str,
     },
 )
@@ -192,66 +152,25 @@ class ExecuteSqlRequestRequestTypeDef(
     pass
 
 
-ExecuteSqlResponseTypeDef = TypedDict(
-    "ExecuteSqlResponseTypeDef",
+ResultSetOptionsTypeDef = TypedDict(
+    "ResultSetOptionsTypeDef",
     {
-        "sqlStatementResults": List["SqlStatementResultTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredExecuteStatementRequestRequestTypeDef = TypedDict(
-    "_RequiredExecuteStatementRequestRequestTypeDef",
-    {
-        "resourceArn": str,
-        "secretArn": str,
-        "sql": str,
-    },
-)
-_OptionalExecuteStatementRequestRequestTypeDef = TypedDict(
-    "_OptionalExecuteStatementRequestRequestTypeDef",
-    {
-        "continueAfterTimeout": bool,
-        "database": str,
-        "formatRecordsAs": RecordsFormatTypeType,
-        "includeResultMetadata": bool,
-        "parameters": Sequence["SqlParameterTypeDef"],
-        "resultSetOptions": "ResultSetOptionsTypeDef",
-        "schema": str,
-        "transactionId": str,
+        "decimalReturnType": DecimalReturnTypeType,
+        "longReturnType": LongReturnTypeType,
     },
     total=False,
 )
 
-
-class ExecuteStatementRequestRequestTypeDef(
-    _RequiredExecuteStatementRequestRequestTypeDef, _OptionalExecuteStatementRequestRequestTypeDef
-):
-    pass
-
-
-ExecuteStatementResponseTypeDef = TypedDict(
-    "ExecuteStatementResponseTypeDef",
-    {
-        "columnMetadata": List["ColumnMetadataTypeDef"],
-        "formattedRecords": str,
-        "generatedFields": List["FieldTypeDef"],
-        "numberOfRecordsUpdated": int,
-        "records": List[List["FieldTypeDef"]],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 FieldTypeDef = TypedDict(
     "FieldTypeDef",
     {
-        "arrayValue": "ArrayValueTypeDef",
-        "blobValue": Union[str, bytes, IO[Any], StreamingBody],
-        "booleanValue": bool,
-        "doubleValue": float,
         "isNull": bool,
+        "booleanValue": bool,
         "longValue": int,
+        "doubleValue": float,
         "stringValue": str,
+        "blobValue": Union[str, bytes, IO[Any], StreamingBody],
+        "arrayValue": "ArrayValueTypeDef",
     },
     total=False,
 )
@@ -264,44 +183,6 @@ RecordTypeDef = TypedDict(
     total=False,
 )
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
-ResultFrameTypeDef = TypedDict(
-    "ResultFrameTypeDef",
-    {
-        "records": List["RecordTypeDef"],
-        "resultSetMetadata": "ResultSetMetadataTypeDef",
-    },
-    total=False,
-)
-
-ResultSetMetadataTypeDef = TypedDict(
-    "ResultSetMetadataTypeDef",
-    {
-        "columnCount": int,
-        "columnMetadata": List["ColumnMetadataTypeDef"],
-    },
-    total=False,
-)
-
-ResultSetOptionsTypeDef = TypedDict(
-    "ResultSetOptionsTypeDef",
-    {
-        "decimalReturnType": DecimalReturnTypeType,
-        "longReturnType": LongReturnTypeType,
-    },
-    total=False,
-)
-
 RollbackTransactionRequestRequestTypeDef = TypedDict(
     "RollbackTransactionRequestRequestTypeDef",
     {
@@ -311,33 +192,6 @@ RollbackTransactionRequestRequestTypeDef = TypedDict(
     },
 )
 
-RollbackTransactionResponseTypeDef = TypedDict(
-    "RollbackTransactionResponseTypeDef",
-    {
-        "transactionStatus": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-SqlParameterTypeDef = TypedDict(
-    "SqlParameterTypeDef",
-    {
-        "name": str,
-        "typeHint": TypeHintType,
-        "value": "FieldTypeDef",
-    },
-    total=False,
-)
-
-SqlStatementResultTypeDef = TypedDict(
-    "SqlStatementResultTypeDef",
-    {
-        "numberOfRecordsUpdated": int,
-        "resultFrame": "ResultFrameTypeDef",
-    },
-    total=False,
-)
-
 StructValueTypeDef = TypedDict(
     "StructValueTypeDef",
     {
@@ -346,27 +200,173 @@ StructValueTypeDef = TypedDict(
     total=False,
 )
 
-UpdateResultTypeDef = TypedDict(
-    "UpdateResultTypeDef",
-    {
-        "generatedFields": List["FieldTypeDef"],
-    },
-    total=False,
-)
-
 ValueTypeDef = TypedDict(
     "ValueTypeDef",
     {
-        "arrayValues": List[Dict[str, Any]],
-        "bigIntValue": int,
-        "bitValue": bool,
-        "blobValue": bytes,
-        "doubleValue": float,
-        "intValue": int,
         "isNull": bool,
+        "bitValue": bool,
+        "bigIntValue": int,
+        "intValue": int,
+        "doubleValue": float,
         "realValue": float,
         "stringValue": str,
+        "blobValue": bytes,
+        "arrayValues": List[Dict[str, Any]],
         "structValue": Dict[str, Any],
     },
     total=False,
 )
+
+BeginTransactionResponseTypeDef = TypedDict(
+    "BeginTransactionResponseTypeDef",
+    {
+        "transactionId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CommitTransactionResponseTypeDef = TypedDict(
+    "CommitTransactionResponseTypeDef",
+    {
+        "transactionStatus": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RollbackTransactionResponseTypeDef = TypedDict(
+    "RollbackTransactionResponseTypeDef",
+    {
+        "transactionStatus": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ResultSetMetadataTypeDef = TypedDict(
+    "ResultSetMetadataTypeDef",
+    {
+        "columnCount": int,
+        "columnMetadata": List[ColumnMetadataTypeDef],
+    },
+    total=False,
+)
+
+ExecuteStatementResponseTypeDef = TypedDict(
+    "ExecuteStatementResponseTypeDef",
+    {
+        "records": List[List[FieldTypeDef]],
+        "columnMetadata": List[ColumnMetadataTypeDef],
+        "numberOfRecordsUpdated": int,
+        "generatedFields": List[FieldTypeDef],
+        "formattedRecords": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+SqlParameterTypeDef = TypedDict(
+    "SqlParameterTypeDef",
+    {
+        "name": str,
+        "value": FieldTypeDef,
+        "typeHint": TypeHintType,
+    },
+    total=False,
+)
+
+UpdateResultTypeDef = TypedDict(
+    "UpdateResultTypeDef",
+    {
+        "generatedFields": List[FieldTypeDef],
+    },
+    total=False,
+)
+
+ResultFrameTypeDef = TypedDict(
+    "ResultFrameTypeDef",
+    {
+        "resultSetMetadata": ResultSetMetadataTypeDef,
+        "records": List[RecordTypeDef],
+    },
+    total=False,
+)
+
+_RequiredBatchExecuteStatementRequestRequestTypeDef = TypedDict(
+    "_RequiredBatchExecuteStatementRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "secretArn": str,
+        "sql": str,
+    },
+)
+_OptionalBatchExecuteStatementRequestRequestTypeDef = TypedDict(
+    "_OptionalBatchExecuteStatementRequestRequestTypeDef",
+    {
+        "database": str,
+        "schema": str,
+        "parameterSets": Sequence[Sequence[SqlParameterTypeDef]],
+        "transactionId": str,
+    },
+    total=False,
+)
+
+
+class BatchExecuteStatementRequestRequestTypeDef(
+    _RequiredBatchExecuteStatementRequestRequestTypeDef,
+    _OptionalBatchExecuteStatementRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredExecuteStatementRequestRequestTypeDef = TypedDict(
+    "_RequiredExecuteStatementRequestRequestTypeDef",
+    {
+        "resourceArn": str,
+        "secretArn": str,
+        "sql": str,
+    },
+)
+_OptionalExecuteStatementRequestRequestTypeDef = TypedDict(
+    "_OptionalExecuteStatementRequestRequestTypeDef",
+    {
+        "database": str,
+        "schema": str,
+        "parameters": Sequence[SqlParameterTypeDef],
+        "transactionId": str,
+        "includeResultMetadata": bool,
+        "continueAfterTimeout": bool,
+        "resultSetOptions": ResultSetOptionsTypeDef,
+        "formatRecordsAs": RecordsFormatTypeType,
+    },
+    total=False,
+)
+
+
+class ExecuteStatementRequestRequestTypeDef(
+    _RequiredExecuteStatementRequestRequestTypeDef, _OptionalExecuteStatementRequestRequestTypeDef
+):
+    pass
+
+
+BatchExecuteStatementResponseTypeDef = TypedDict(
+    "BatchExecuteStatementResponseTypeDef",
+    {
+        "updateResults": List[UpdateResultTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+SqlStatementResultTypeDef = TypedDict(
+    "SqlStatementResultTypeDef",
+    {
+        "resultFrame": ResultFrameTypeDef,
+        "numberOfRecordsUpdated": int,
+    },
+    total=False,
+)
+
+ExecuteSqlResponseTypeDef = TypedDict(
+    "ExecuteSqlResponseTypeDef",
+    {
+        "sqlStatementResults": List[SqlStatementResultTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
